#
# Fedora spec file for php-doctrine-dbal
#
# Copyright (c) 2013-2016 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     doctrine
%global github_name      dbal
%global github_version   2.4.5
%global github_commit    5a1f4bf34d61d997ccd9f0539fbc14c7a772aa16

%global composer_vendor  doctrine
%global composer_project dbal

# "php": ">=5.3.2"
%global php_min_ver 5.3.2
# "doctrine/common": "~2.4"
#     NOTE: Min version not 2.4 because autoloader required
%global doctrine_common_min_ver 2.4.3
%global doctrine_common_max_ver 3.0
# "symfony/console": "~2.0"
#     NOTE: Min version not 2.0 because autoloader required
%global symfony_console_min_ver 2.3.31
%global symfony_console_max_ver 3.0

%{!?phpdir:  %global phpdir  %{_datadir}/php}

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

Name:      php-%{composer_vendor}-%{composer_project}
Version:   %{github_version}
Release:   1%{?github_release}%{?dist}
Summary:   Doctrine Database Abstraction Layer (DBAL)

Group:     Development/Libraries
License:   MIT
URL:       http://www.doctrine-project.org/projects/dbal

# GitHub export does not include tests.
# Run php-doctrine-dbal-get-source.sh to create full source.
Source0:   %{name}-%{version}-%{github_commit}.tar.gz
Source1:   %{name}-get-source.sh

# Update bin script
# 1) Add she-bang
# 2) Use custom autoloader
Patch0:    %{name}-bin.patch

BuildArch: noarch
# Library version value check
BuildRequires: php-cli
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language)                 >= %{php_min_ver}
BuildRequires: php-composer(doctrine/common) >= %{doctrine_common_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-composer(symfony/console) >= %{symfony_console_min_ver}
## phpcompatinfo (computed from version 2.4.5)
BuildRequires: php-date
BuildRequires: php-json
BuildRequires: php-pcre
BuildRequires: php-pdo
BuildRequires: php-reflection
BuildRequires: php-spl
%endif

# composer.json
Requires:  php(language)                 >= %{php_min_ver}
Requires:  php-composer(doctrine/common) <  %{doctrine_common_max_ver}
Requires:  php-composer(doctrine/common) >= %{doctrine_common_min_ver}
# composer.json: optional
Requires:  php-composer(symfony/console) <  %{symfony_console_max_ver}
Requires:  php-composer(symfony/console) >= %{symfony_console_min_ver}
# phpcompatinfo (computed from version 2.4.5)
Requires:  php-date
Requires:  php-json
Requires:  php-pcre
Requires:  php-pdo
Requires:  php-spl

# Composer
Provides:  php-composer(%{composer_vendor}/%{composer_project}) = %{version}
# PEAR
Provides:  php-pear(pear.doctrine-project.org/DoctrineDBAL) = %{version}
# Rename
Obsoletes: php-doctrine-DoctrineDBAL < %{version}
Provides:  php-doctrine-DoctrineDBAL = %{version}

%description
The Doctrine database abstraction & access layer (DBAL) offers a lightweight
and thin runtime layer around a PDO-like API and a lot of additional, horizontal
features like database schema introspection and manipulation through an OO API.

The fact that the Doctrine DBAL abstracts the concrete PDO API away through the
use of interfaces that closely resemble the existing PDO API makes it possible
to implement custom drivers that may use existing native or self-made APIs. For
example, the DBAL ships with a driver for Oracle databases that uses the oci8
extension under the hood.


%prep
%setup -qn %{github_name}-%{github_commit}

: Patch bin script
%patch0 -p1

: Remove empty file
rm -f lib/Doctrine/DBAL/README.markdown

: Remove executable bits
chmod a-x \
    lib/Doctrine/DBAL/Types/JsonArrayType.php \
    lib/Doctrine/DBAL/Types/SimpleArrayType.php


%build
: Create autoloader
cat <<'AUTOLOAD' | tee lib/Doctrine/DBAL/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 *
 * @return \Symfony\Component\ClassLoader\ClassLoader
 */

if (!isset($fedoraClassLoader) || !($fedoraClassLoader instanceof \Symfony\Component\ClassLoader\ClassLoader)) {
    if (!class_exists('Symfony\\Component\\ClassLoader\\ClassLoader', false)) {
        require_once '%{phpdir}/Symfony/Component/ClassLoader/ClassLoader.php';
    }

    $fedoraClassLoader = new \Symfony\Component\ClassLoader\ClassLoader();
    $fedoraClassLoader->register();
}

$fedoraClassLoader->addPrefix('Doctrine\\DBAL\\', dirname(dirname(__DIR__)));

// Required dependencies
require_once '%{phpdir}/Doctrine/Common/autoload.php';
require_once '%{phpdir}/Symfony/Component/Console/autoload.php';

return $fedoraClassLoader;
AUTOLOAD


%install
: Lib
mkdir -p %{buildroot}/%{_datadir}/php
cp -rp lib/Doctrine %{buildroot}/%{_datadir}/php/

: Bin
mkdir -p %{buildroot}/%{_bindir}
install -pm 0755 bin/doctrine-dbal.php %{buildroot}/%{_bindir}/doctrine-dbal


%check
: Library version value check
%{_bindir}/php -r '
    require_once "%{buildroot}%{phpdir}/Doctrine/DBAL/Version.php";
    $version = \Doctrine\DBAL\Version::VERSION;
    echo "Version $version (expected %{version})\n";
    exit(version_compare("%{version}", "$version", "=") ? 0 : 1);
'

%if %{with_tests}
: Remove load of TestInit
rm -f tests/Doctrine/Tests/TestInit.php
grep -r --files-with-matches 'TestInit' tests | xargs sed -i '/TestInit/d'

: Create tests bootstrap
cat > bootstrap.php <<'BOOTSTRAP'
<?php
$fedoraClassLoader =
    require_once '%{buildroot}%{phpdir}/Doctrine/DBAL/autoload.php';

$fedoraClassLoader->addPrefix('Doctrine\\Tests\\', __DIR__.'/tests');
BOOTSTRAP

%{_bindir}/phpunit --bootstrap bootstrap.php
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Doctrine/DBAL
%{_bindir}/doctrine-dbal


%changelog
* Fri Jul 22 2016 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.4.5-1
- Updated to 2.4.5 (RHBZ #1354049)
- Removed primary index patch
- Added autoloader
- Added running of tests and library version value check

* Fri Jun 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.4.2-4
- Added php-composer(%%{composer_vendor}/%%{composer_project}) virtual provide
- Updated Doctrine dependencies to use php-composer virtual provides

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Jan 07 2014 Adam Williamson <awilliam@redhat.com> - 2.4.2-2
- primary_index: one OwnCloud patch still isn't in upstream

* Sat Jan 04 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.4.2-1
- Updated to 2.4.2
- Conditional %%{?dist}

* Tue Dec 31 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.4.1-2.20131231gitd08b11c
- Updated to latest snapshot
- Removed patches (pulled into latest snapshot)

* Sun Dec 29 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 2.4.1-1
- Initial package
